@@ -6,7 +6,7 @@
 # Classes dealing directly with OpsRamp Sites.
 # Sites are used to organise resources by geographical location.
 #
-# (c) Copyright 2019 Hewlett Packard Enterprise Development LP
+# (c) Copyright 2019-2020 Hewlett Packard Enterprise Development LP
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -32,7 +32,10 @@ class Sites(ApiWrapper):
         return self.api.get(suffix)
 
     def search(self, pattern=''):
-        return self.api.get('/search?%s' % pattern)
+        suffix = 'search'
+        if pattern:
+            suffix += '?' + pattern
+        return self.api.get(suffix)
 
     def create(self, definition):
         return self.api.post('', json=definition)
